==> html-json-highlight-1.0.0.tgz: package/srcs/app.js <==
'use strict';

class HtmlJsonBlock {
	static Colors = {
		SquareBracket: "#FF1493",
		Key: "#008B8B",
		Colon: "#FF1493",
		String: "#DC143C",
		Number: "#32CD32",
		Boolean: "#DAA520",
		Null: "#8B4513",
		Object: "#556B2F",
		Array: "#7B68EE"
	}
	

	constructor(body) {
		this.raw = body;
		this.newBody = [
			'{'
		];

		Object.keys(body).forEach((value, index, arr) => {
			const subValue = Object.values(body);
			if(index === arr.length - 1)
			this.newBody.push(`<font color="${HtmlJsonBlock.Colors.Key}">"${value}"</font>: ${this.valueColor(subValue[index])}`);
			else
			this.newBody.push(`<font color="${HtmlJsonBlock.Colors.Key}">"${value}"</font>: ${this.valueColor(subValue[index])}<font color="${HtmlJsonBlock.Colors.Colon}">, </font> `);
		});
		this.newBody.push('}');
		this.body.bind(this);
	}

	color(color, value, type) {
		switch(type) {
			case 'String':
				return `<font color="${color}">"${value}"</font>`;
			break;
	
			case 'Number':
				return `<font color="${color}">${value}</font>`;
			break;
			
			case 'Boolean':
				return `<font color="${color}">${value}</font>`;
			break;
			
			case 'Null':
				return `<font color="${color}">${value}</font>`
			break;
			
			case 'Object':
				const subObject = (new HtmlJsonBlock(value)).body();
				return `<font color="${HtmlJsonBlock.Colors.Object}">{</font><font color="${color}">${subObject.substring(1, subObject.length - 1)}</font><font color="${HtmlJsonBlock.Colors.Object}">}</font>`;
			break;

			case 'Array':
				return [`<font color="${HtmlJsonBlock.Colors.Array}">[</font>`, value.map(value => `<font color="${color}">${this.valueColor(value)}</font>`).join(', '), `<font color="${HtmlJsonBlock.Colors.Array}">]</font>`].join('')
			break;
		}
	}

	valueColor(value) {
		switch(Object.prototype.toString.call(value)) {
			case '[object String]':
				return this.color(HtmlJsonBlock.Colors.String, value, 'String');
			break;

			case '[object Number]':
				return this.color(HtmlJsonBlock.Colors.Number, value, 'Number');
			break;

			case '[object Boolean]':
				return this.color(HtmlJsonBlock.Colors.Boolean, value, 'Boolean');
			break;
			
			case '[object Null]':
				return this.color(HtmlJsonBlock.Colors.Null, value, 'Null');
			break;

			case '[object Object]':
				return this.color(HtmlJsonBlock.Colors.Object, value, 'Object');
			break;

			case '[object Array]':
				return this.color(HtmlJsonBlock.Colors.Array, value, 'Array');
			break;
		}
	}
	body(status) {
		if(status)
		return this.raw;
		else
		return this.newBody.join('')
	}
};

export default HtmlJsonBlock;

==> html-json-highlight-1.0.3.tgz: package/srcs/app.js <==
'use strict';

class HtmlJsonBlock {
	static Colors = {
		SquareBracket: "#FF1493",
		Key: "#008B8B",
		Colon: "#FF1493",
		String: "#DC143C",
		Number: "#32CD32",
		Boolean: "#DAA520",
		Null: "#8B4513",
		Object: "#556B2F",
		Array: "#7B68EE"
	}
	

	constructor(body) {
		this.index = 1;
		this.raw = body;
		this.newBody = [
			'{<br />'
		];

		Object.keys(body).forEach((value, index, arr) => {
			const subValue = Object.values(body);
			if(index === arr.length - 1) {
				this.newBody.push(`${this.space(2)}<font color="${HtmlJsonBlock.Colors.Key}">"${value}"</font>: ${this.valueColor(subValue[index])}`);
			} else {
				this.newBody.push(`${this.space(2)}<font color="${HtmlJsonBlock.Colors.Key}">"${value}"</font>: ${this.valueColor(subValue[index])}<font color="${HtmlJsonBlock.Colors.Colon}">, </font><br />`);
			}
		});
		this.newBody.push('<br />}');
		this.body.bind(this);
	}

	color(color, value, type) {
		switch(type) {
			case 'String':
				return `<font color="${color}">"${value}"</font>`;
			break;
	
			case 'Number':
				return `<font color="${color}">${value}</font>`;
			break;
			
			case 'Boolean':
				return `<font color="${color}">${value}</font>`;
			break;
			
			case 'Null':
				return `<font color="${color}">${value}</font>`
			break;
			
			case 'Object':
				this.subObject = (new HtmlJsonBlock(value)).body();
				this.subObject = this.subObject.substring(1, this.subObject.length - 1);
				return `<font color="${HtmlJsonBlock.Colors.Object}">{</font><font color="${color}">${this.subObject}</font><font color="${HtmlJsonBlock.Colors.Object}">${this.space(2)}}</font>`;
			break;

			case 'Array':
				return [`<font color="${HtmlJsonBlock.Colors.Array}">[</font>`, value.map(value => `<font color="${color}">${this.valueColor(value)}</font>`).join(', '), `<font color="${HtmlJsonBlock.Colors.Array}">]</font>`].join('')
			break;
		}
	}

	valueColor(value) {
		switch(Object.prototype.toString.call(value)) {
			case '[object String]':
				return this.color(HtmlJsonBlock.Colors.String, value, 'String');
			break;

			case '[object Number]':
				return this.color(HtmlJsonBlock.Colors.Number, value, 'Number');
			break;

			case '[object Boolean]':
				return this.color(HtmlJsonBlock.Colors.Boolean, value, 'Boolean');
			break;
			
			case '[object Null]':
				return this.color(HtmlJsonBlock.Colors.Null, value, 'Null');
			break;

			case '[object Object]':
				return this.color(HtmlJsonBlock.Colors.Object, value, 'Object');
			break;

			case '[object Array]':
				return this.color(HtmlJsonBlock.Colors.Array, value, 'Array');
			break;
		}
	}
	
	space(quantity) {
		return new Array(quantity).fill('&nbsp;').join('');
	}
	
	body(status) {
		if(status)
		return this.raw;
		else
		return this.newBody.join('')
	}
};

export default HtmlJsonBlock;
